
NIFTy user guide
================

This guide is an overview and explains the main conceptual idea behind NIFTy (Numerical Information Field Theory).
More details on the API can be found at the `API reference <../mod/nifty8.html>`_.
In the following, an online version of the latest publication describing NIFTy is provided.
The publication below gives a quick overview of the core concepts powering NIFTy and showcases a simple example.

.. toctree::
   :maxdepth: 1
 
   paper

.. toctree::
   :maxdepth: 1

   0_intro

The following page provides a demonstration of the Correlated field model in NIFTy.re:

.. toctree::
   :maxdepth: 1

   niftyre_getting_started_4_CorrelatedFields

In-depth discussion of important concepts in NIFTy and details on how to cite NIFTy is provided on the following pages:

.. toctree::
   :maxdepth: 1

   ift
   approximate_inference
   citations

In the following are guides to the NumPy-based NIFTy.
They serve as reference but are likely not relevant anymore for new projects.

.. toctree::
   :maxdepth: 1

   old_nifty

